#
# spec file for package xsettingsd
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xsettingsd
Version:        1.0.2
Release:        1.12
Summary:        Provides settings to X11 applications
License:        BSD-3-Clause
Group:          System/X11/Utilities
URL:            https://github.com/derat/xsettingsd
Source:         https://github.com/derat/xsettingsd/archive/refs/tags/v%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig
BuildRequires:  scons
BuildRequires:  xz
BuildRequires:  pkgconfig(x11)

%description
xsettingsd is a daemon that implements the XSETTINGS specification.
It is intended to be small, fast, and minimally dependent on other
libraries. It can serve as an alternative to mate-settings-daemon for users
who are not using the MATE desktop environment but who still run GTK+
applications and want to configure things such as themes, font
antialiasing/hinting, and UI sound effects.

%prep
%setup -q
%if 0%{?suse_version} < 1210
# -Wno-narrowing makes the build to fail.
sed -i 's/ -Wno-narrowing//' SConstruct
%endif

%build
CFLAGS="%{optflags}" CXXFLAGS="%{optflags}" scons %{?_smp_mflags}

%install
for file in %{name} dump_xsettings; do
    install -Dpm 0755 $file %{buildroot}%{_bindir}/$file
    install -Dpm 0644 $file.1 %{buildroot}%{_mandir}/man1/$file.1
done

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_bindir}/dump_xsettings
%{_mandir}/man?/%{name}.?%{?ext_man}
%{_mandir}/man?/dump_xsettings.?%{?ext_man}

%changelog
* Tue Jan  4 2022 Dirk Müller <dmueller@suse.com>
- update to 1.0.2:
  * Fix from Phil Miller to make dump_xsettingsd return 1 on error.
  * Support for building using CMake from Andreas Sturmlechner and Peter Eszlari.
  * systemd service file from Peter Eszlari.
* Sat May  1 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file (move license to licensedir)
* Tue Nov 28 2017 crrodriguez@opensuse.org
- Buildrequire pkgconfig(x11) not the whole of xorg-x11-devel.
* Thu Nov 23 2017 sor.alexei@meowr.ru
- Update to version 0.0+git20171105:
  * Add Python3 Support in SConstruct.
- Use _service to get the git tarball.
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 0.0~git20170402 (changes since 0.0~git20150615):
  * Use LINKFLAGS instead of LDFLAGS.
    It turns out scons uses its own name for this.
  * Update home page in manpages.
- Change the RPM group to System/X11/Utilities.
* Sat Jun 20 2015 sor.alexei@meowr.ru
- Update to 0.0~git20150615:
  * Make tests work with source-only libgtest.
  * Fall back to checking XDG locations for config files.
* Sat Nov  1 2014 sor.alexei@meowr.ru
- Update to 0.0~git20141123:
  * fix an issue that int values returned by
    ConfigParser::FileCharStream::GetCharImpl() were cast to chars,
    resulting in EOF getting lost
- Add missing CXXFLAGS.
- Add SLE 11 support.
* Wed Oct  8 2014 sor.alexei@meowr.ru
- Update to 0.0~git20140814:
  * allow negative int values
* Wed Apr 30 2014 andreas.stieger@gmx.de
- Fix warning standard-dir-owned-by-package /usr/share/man/man1.
* Wed Mar 12 2014 sor.alexei@meowr.ru
- Initial package.
